@@ -4,7 +4,7 @@
 #' \cite{Fay and Herriot (1979)}. Empirical best linear unbiased predictors 
 #' (EBLUPs) and mean squared error (MSE) estimates are provided. Additionally, 
 #' different extensions of the standard Fay-Herriot model are available: \cr 
-#' Adjusted estimation methods for the variance of the random effects (see also \cite{Li 
+#' Adjusted estimation methods for the variance of the random effects (see \cite{Li 
 #' and Lahiri (2010)} and \cite{Yoshimori and Lahiri (2014)}) are offered. Log 
 #' and arcsin transformation for the dependent variable and two types of 
 #' backtransformation can be chosen - a crude version
@@ -13,7 +13,7 @@
 #' \cite{Hadam et al. (2020)} for arcsin transformed variables. A spatial extension 
 #' to the Fay-Herriot model following \cite{Petrucci and Salvati (2006)} is also 
 #' included. In addition, it is possible to estimate a robust version of the 
-#' standard and of the spatial model (see also \cite{Warnholz (2017)}). Finally, 
+#' standard and of the spatial model (see \cite{Warnholz (2016)}). Finally, 
 #' a Fay-Herriot model can be estimated when the auxiliary information is measured 
 #' with error following \cite{Ybarra and Lohr (2008)}.
 #'
@@ -40,9 +40,9 @@
 #' (iv) adjusted ML following \cite{Li and Lahiri (2010)} ("\code{ampl}"),
 #' (v) adjusted REML following \cite{Yoshimori and Lahiri (2014)} ("\code{amrl_yl}"),
 #' (vi) adjusted ML following \cite{Yoshimori and Lahiri (2014)} ("\code{ampl_yl}"),
-#' (vii) robustified maximum likelihood with robust eblup prediction following
+#' (vii) robustified maximum likelihood with robust EBLUP prediction following
 #' \cite{Warnholz (2017)} ("\code{reblup}"), 
-#' (viii) robustified maximum likelihood with robust and bias-corrected eblup 
+#' (viii) robustified maximum likelihood with robust and bias-corrected EBLUP 
 #' prediction following \cite{Warnholz (2017)} ("\code{reblupbc}"),
 #' (ix) estimation of the measurement error model of \cite{Ybarra and Lohr 
 #' (2008)} ("\code{me}"). Defaults to "\code{reml}".
@@ -58,27 +58,27 @@
 #' @param k numeric tuning constant. Required argument when the robust version of 
 #' the standard or spatial Fay-Herriot model is chosen. Defaults to \code{1.345}. 
 #' For detailed information, please refer to \cite{Warnholz (2016)}.
-#' @param c numeric multiplier constant used in the bias corrected version of the 
+#' @param mult_constant numeric multiplier constant used in the bias corrected version of the 
 #' robust estimation methods. Required argument when the robust version of 
 #' the standard or spatial Fay-Herriot model is chosen. Default is to make no 
-#' correction for realizations of direct estimator within \code{c = 1} times the 
-#' standard deviation of direct estimator. For detailed information, please refer 
-#' to \cite{Warnholz (2016)}.
+#' correction for realizations of direct estimator within \code{mult_constant = 1} 
+#' times the standard deviation of direct estimator. For detailed information, 
+#' please refer to \cite{Warnholz (2016)}.
 #' @param transformation a character that determines the type of transformation 
 #' of the dependent variable and of the sampling variances. Methods that can be chosen
 #' (i) no transformation ("\code{no}"),
 #' (ii) log transformation ("\code{log}") of the dependent variable and of 
-#' the sampling variances following \cite{Neves et al. (2013)}, 
+#' the sampling variances, 
 #' (iii) arcsin transformation ("\code{arcsin}") of the dependent variable and of 
-#' the sampling variances following \cite{Jiang et al. (2001)}. Defaults to "\code{no}".
+#' the sampling variances following. Defaults to "\code{no}". For more information, 
+#' how the direct estimate and its variance are transformed, please see the package 
+#' vignette "A Framework for Producing Small Area Estimates Based on Area-Level Models in R".
 #' @param backtransformation a character that determines the type of backtransformation 
 #' of the EBLUPs and MSE estimates. Required argument when a transformation is chosen. 
 #' Available methods are 
-#' (i) crude bias-correction following \cite{Neves et al. (2013)} and 
-#' \cite{Rao and Molina (2015)} when the log transformation is chosen 
-#' ("\code{bc_crude}"),
-#' (ii) bias-correction following \cite{Slud and Maiti (2006)} when the 
-#' log transformations is chosen ("\code{bc_sm}"),
+#' (i) crude bias-correction following \cite{Rao (2015)} when the log transformation 
+#' is chosen ("\code{bc_crude}"), (ii) bias-correction following \cite{Slud and Maiti (2006)} 
+#' when the log transformations is chosen ("\code{bc_sm}"),
 #' (iii) naive back transformation when the arcsin transformation 
 #' is chosen ("\code{naive}"),
 #' (iii) bias-corrected back transformation following \cite{Hadam et al. (2020)} 
@@ -139,24 +139,21 @@
 #' robust extensions of the Fay-Herriot model. For an extensive overview of the possible 
 #' MSE options, please refer to the vignette. Required argument when 
 #' \code{MSE = TRUE}. Defaults to "\code{analytical}".
-#' @param B a number determining the number of bootstrap iterations. When a 
-#' bootstrap MSE estimator is chosen, \code{B} regulates the MSE estimation. 
-#' When the standard FH model is applied and \code{B} is not \code{NULL}, the 
-#' information criteria by Marhuenda et al. (2014) are computed. The number must 
-#' be greater than 1. Defaults to 50. For practical applications, 
-#' values larger than 200 are recommended.
+#' @param B either a single number or a numeric vector with two elements. The 
+#' single number or the first element defines the number of bootstrap iterations 
+#' when a bootstrap MSE estimator is chosen. When the standard FH 
+#' model is applied and the information criteria by Marhuenda et al. (2014) 
+#' should be computed, the second element of \code{B} is needed and must be 
+#' greater than 1. Defaults to c(50,0). For practical applications, values larger 
+#' than 200 are recommended.
 #' @param seed an integer to set the seed for the random number generator. For 
 #' the usage of random number generation see details. If seed is set to 
 #' \code{NULL}, seed is chosen randomly. Defaults to \code{123}.
-#' @return An object of class "fh", "model" and "emdi" that provides estimators 
+#' @return An object of class "fh", "emdi" that provides estimators 
 #' for regional disaggregated indicators like means and ratios and optionally 
-#' corresponding MSE estimates. Generic functions such as \code{\link{compare}},
-#' \code{\link{compare_plot}}, \code{\link{estimators}}, \code{\link{print}}, 
-#' \code{\link{plot}}, \code{\link{step}} and \code{\link{summary}} have methods 
-#' that can be used to obtain further information. Additionally, for the standard 
-#' Fay-Herriot model that is estimated via ML variance estimation a model selection 
-#' function is provided (\code{\link{step}}). See \code{\link{emdiObject}} for 
-#' descriptions of components of objects of class "fh".
+#' corresponding MSE estimates. Several generic functions have methods for the 
+#' returned object. For a full list and descriptions of the components of objects 
+#' of class "emdi", see \code{\link{emdiObject}}.
 #' @details In the bootstrap approaches, random number generation is used. Thus, a 
 #' seed is set by the argument \code{seed}. \cr \cr
 #' Out-of-sample EBLUPs are available for all area-level models except for the 
@@ -174,7 +171,6 @@
 #' estimation, "Proceeding of the Section on Survey Research Methods", American 
 #' Statistical Association, 473 - 477. \cr \cr
 #' Datta, G. S. and Lahiri, P. (2000), A unified measure of uncertainty of 
-#' estimated best linear unbiased predictors in small area estimation problems, 
 #' Statistica Sinica 10(2), 613-627. \cr \cr
 #' Fay, R. E. and Herriot, R. A. (1979), Estimates of income for small places:
 #' An application of James-Stein procedures to census data, Journal of the 
@@ -185,7 +181,7 @@
 #' Data Analysis, 52, 5242–5252. \cr \cr
 #' Hadam, S., Wuerz, N. and Kreutzmann, A.-K. (2020), Estimating 
 #' regional unemployment with mobile network data for Functional Urban Areas in 
-#' Germany, Freie Universitaet Berlin. \cr \cr
+#' Germany, Refubium - Freie Universitaet Berlin Repository, 1-28. \cr \cr
 #' Jiang, J., Lahiri, P., Wan, S.-M. and Wu, C.-H. (2001), Jackknifing in the 
 #' Fay–Herriot model with an example. In Proc. Sem. Funding Opportunity in 
 #' Survey Research, Washington DC: Bureau of Labor Statistics, 75–97. \cr \cr
@@ -211,13 +207,13 @@
 #' Fay-Herriot models, Journal of the Royal Statistical Society:Series B 68(2),
 #' 239-257.\cr \cr
 #' Warnholz, S. (2016), saeRobust: Robust small area estimation. R package. \cr \cr
+#' Warnholz, S. (2016b). Small area estimation using robust extensions to area 
+#' level models. Ph.D. thesis, Freie Universitaet Berlin. \cr \cr
 #' Ybarra, L. and Lohr, S. (2008), Small area estimation when auxiliary 
 #' information is measured with error, Biometrika, 95(4), 919-931.\cr \cr
 #' Yoshimori, M. and Lahiri, P. (2014), A new adjusted maximum likelihood method
 #' for the Fay-Herriot small area model, Journal of Multivariate Analysis 124, 
-#' 281-294. \cr \cr
-#' Warnholz, S. (2016b). Small area estimation using robust extensions to area 
-#' level models. Ph.D. thesis, Freie Universitaet Berlin.
+#' 281-294. 
 #' @examples
 #' \donttest{
 #' # Loading data - population and sample data
@@ -237,7 +233,7 @@
 #' fh_arcsin <- fh(fixed = MTMED ~ cash + age_ben + rent + house_allow,
 #' vardir = "Var_MTMED", combined_data = combined_data, domains = "Domain", 
 #' method = "ml", transformation = "arcsin", backtransformation = "bc", 
-#' eff_smpsize = "n", MSE = TRUE, mse_type = "boot", B = 50)
+#' eff_smpsize = "n", MSE = TRUE, mse_type = "boot", B = c(50,0))
 #' 
 #' # Example 3: Spatial Fay-Herriot model
 #' # Load proximity matrix
@@ -248,11 +244,9 @@
 #' mse_type = "analytical")
 #' 
 #' # Example 4: Robust Fay-Herriot model 
-#' # Please note that the example runs for several minutes. For a short check
-#' # change B to a lower value.
 #' fh_robust <- fh(fixed = Mean ~ cash + self_empl, vardir = "Var_Mean", 
 #' combined_data = combined_data, domains = "Domain", method = "reblupbc", 
-#' k = 1.345, c = 1, MSE = TRUE, mse_type = "pseudo")
+#' k = 1.345, mult_constant = 1, MSE = TRUE, mse_type = "pseudo")
 #' 
 #' # Example 5: Ybarra-Lohr model
 #' # Create MSE array
@@ -276,16 +270,16 @@
 
 
 fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
-               interval = NULL, k = 1.345, c = 1, transformation = "no",
+               interval = NULL, k = 1.345, mult_constant = 1, transformation = "no",
                backtransformation = NULL, eff_smpsize = NULL,
                correlation = "no", corMatrix = NULL, 
                Ci = NULL, tol = 0.0001, maxit = 100,
-               MSE = FALSE, mse_type = "analytical", B = 50, seed = 123) {
+               MSE = FALSE, mse_type = "analytical", B = c(50,0), seed = 123) {
 
   # Agrument checking ----------------------------------------------------------
   fh_combinations(fixed = fixed, vardir = vardir, combined_data = combined_data, 
                   domains = domains, method = method, interval = interval, k = k, 
-                  c = c, transformation = transformation, 
+                  mult_constant = mult_constant, transformation = transformation, 
                   backtransformation = backtransformation, eff_smpsize = eff_smpsize, 
                   correlation = correlation, corMatrix = corMatrix,  
                   Ci = Ci, tol = tol, maxit = maxit, MSE = MSE, mse_type = mse_type, 
@@ -293,7 +287,7 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
   
   fh_check(fixed = fixed, vardir = vardir, combined_data = combined_data, 
            domains = domains, method = method, interval = interval, k = k, 
-           c = c, transformation = transformation, 
+           mult_constant = mult_constant, transformation = transformation, 
            backtransformation = backtransformation, eff_smpsize = eff_smpsize, 
            correlation = correlation, corMatrix = corMatrix, 
            Ci = Ci, tol = tol, maxit = maxit, MSE = MSE, mse_type = mse_type, 
@@ -326,6 +320,11 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
   upper <- var(framework$direct)
   interval <- c(0, upper)
   }
+  
+  # Number of bootstrap iterations
+  if (length(B) == 1){
+    B <- c(B, 0)
+  }
 
   if (!(method == "reblup" | method == "reblupbc")) {
     # Estimate sigma u ---------------------------------------------------------
@@ -343,9 +342,9 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
         Gamma$Gamma <- NA
         Gamma$Gamma[framework$obs_dom == TRUE] <- as.numeric(eblup$gamma)
         # Criteria for model selection -----------------------------------------
-         criteria <- model_select(framework = framework, sigmau2 = sigmau2, 
+        criteria <- model_select(framework = framework, sigmau2 = sigmau2, 
                                   method = method, interval = interval, 
-                                  eblup = eblup, B = B, vardir = vardir,
+                                  eblup = eblup, B = B[2], vardir = vardir,
                                   transformation = transformation,
                                   combined_data = framework$combined_data)
       }
@@ -356,7 +355,7 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
         # Criteria for model selection -----------------------------------------
         criteria <- model_select(framework = framework, sigmau2 = sigmau2,
                                  method = method, interval = interval, 
-                                 eblup = eblup, B = B, vardir = vardir,
+                                 eblup = eblup, B = B[2], vardir = vardir,
                                  transformation = transformation,
                                  combined_data = framework$combined_data)
       }
@@ -371,7 +370,7 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
       # Criteria for model selection -----------------------------------------
       criteria <- model_select(framework = framework, sigmau2 = sigmau2,
                                method = method, interval = interval, 
-                               eblup = eblup, B = B, vardir = vardir,
+                               eblup = eblup, B = B[2], vardir = vardir,
                                transformation = transformation,
                                combined_data = framework$combined_data)
     }
@@ -387,7 +386,7 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
                                 sigmau2 = sigmau2, vardir = vardir, Ci = Ci,
                                 eblup = eblup, transformation = transformation,
                                 method = method, interval = interval,
-                                mse_type = mse_type, B = B)
+                                mse_type = mse_type, B = B[1])
         MSE <- MSE_data$MSE_data
         MSE_method <- MSE_data$MSE_method
         if (mse_type == "spatialnonparboot" | mse_type == "spatialnonparbootbc" |
@@ -417,13 +416,16 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
                       model = list(coefficients = eblup$coefficients,
                                    variance = sigmau2,
                                    random_effects = eblup$random_effects,
+                                   fitted = eblup$fitted,
                                    real_residuals = eblup$real_res,
                                    std_real_residuals = eblup$std_real_res,
                                    model_select = criteria,
                                    correlation = correlation,
-                                   seed = seed),
+                                   seed = seed,
+                                   beta_vcov = eblup$beta_vcov),
                       framework = framework[c("direct", "vardir", "N_dom_smp",
-                                              "N_dom_unobs")],
+                                              "N_dom_unobs", "combined_data", 
+                                              "domains")],
                       transformation = list(transformation = transformation,
                                             backtransformation = backtransformation),
                       method = list(method = method,
@@ -442,13 +444,16 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
                       model = list(coefficients = eblup$coefficients,
                                    variance = sigmau2,
                                    random_effects = eblup$random_effects,
+                                   fitted = eblup$fitted,
                                    real_residuals = eblup$real_res,
                                    std_real_residuals = eblup$std_real_res,
                                    model_select = criteria,
                                    correlation = correlation,
-                                   seed = seed),
+                                   seed = seed,
+                                   beta_vcov = eblup$beta_vcov),
                       framework = framework[c("direct", "vardir", "N_dom_smp",
-                                              "N_dom_unobs")],
+                                              "N_dom_unobs", "combined_data", 
+                                              "domains", "W")],
                       transformation = list(transformation = transformation,
                                             backtransformation = backtransformation),
                       method = list(method = method,
@@ -472,14 +477,17 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
                     model = list(coefficients = eblup$coefficients,
                                  variance = sigmau2,
                                  random_effects = eblup$random_effects,
+                                 fitted = eblup$fitted,
                                  real_residuals = eblup$real_res,
                                  std_real_residuals = eblup$std_real_res,
                                  gamma = Gamma,
                                  model_select = criteria,
                                  correlation = correlation,
-                                 seed = seed),
+                                 seed = seed,
+                                 beta_vcov = eblup$beta_vcov),
                     framework = framework[c("direct", "vardir", "N_dom_smp",
-                                            "N_dom_unobs")],
+                                            "N_dom_unobs", "combined_data", 
+                                            "domains")],
                     transformation = list(transformation = transformation,
                                           backtransformation = backtransformation),
                     method = list(method = method,
@@ -495,14 +503,17 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
                     transform_param = NULL,
                     model = list(coefficients = eblup$coefficients,
                                  variance = sigmau2$sigmau_YL,
-                                 random_effects = eblup$random_effects,
+                                 random_effects = as.matrix(eblup$random_effects),
+                                 fitted = eblup$fitted,
                                  real_residuals = eblup$real_res,
                                  std_real_residuals = eblup$std_real_res,
                                  gamma = Gamma,
                                  model_select = criteria,
-                                 correlation = correlation),
+                                 correlation = correlation,
+                                 beta_vcov = eblup$beta_vcov),
                     framework = framework[c("direct", "vardir", "N_dom_smp",
-                                            "N_dom_unobs")],
+                                            "N_dom_unobs", "combined_data", 
+                                            "domains", "Ci")],
                     transformation = list(transformation = transformation,
                                           backtransformation = backtransformation),
                     method = list(method = method,
@@ -540,22 +551,25 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
                                      method = method, interval = interval,
                                      MSE = MSE,
                                      mse_type = mse_type,
-                                     B = B)
+                                     B = B[1])
       
       out <- list(ind = result_data$EBLUP_data,
                   MSE = result_data$MSE_data,
                   transform_param = NULL,
                   model = list(coefficients = eblup$coefficients,
                                variance = sigmau2,
-                               random_effects = eblup$random_effects[, 1],
+                               random_effects = as.matrix(eblup$random_effects[, 1]),
+                               fitted = eblup$fitted,
                                real_residuals = eblup$real_res[, 1],
                                std_real_residuals = eblup$std_real_res[, 1],
                                gamma = Gamma,
                                model_select = criteria, 
                                correlation = correlation,
-                               seed = seed),
+                               seed = seed,
+                               beta_vcov = eblup$beta_vcov),
                   framework = framework[c("direct", "vardir", "N_dom_smp",
-                                          "N_dom_unobs")],
+                                          "N_dom_unobs", "combined_data", 
+                                          "domains")],
                   transformation = list(transformation = transformation,
                                         backtransformation = backtransformation),
                   method = list(method = method,
@@ -569,7 +583,7 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
     # Standard EBLUP -----------------------------------------------------------
     eblup <- eblup_robust(framework = framework, vardir = vardir, 
                           combined_data = combined_data,
-                          method = method, k = k, c = c, 
+                          method = method, k = k, mult_constant = mult_constant, 
                           correlation = correlation, corMatrix = corMatrix)
     
     # MSE ----------------------------------------------------------------------
@@ -577,7 +591,7 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
       MSE_data <- wrapper_MSE(framework = framework, 
                               combined_data = framework$combined_data,
                               vardir = vardir, eblup = eblup,
-                              mse_type = mse_type, method = method, B = B)
+                              mse_type = mse_type, method = method, B = B[1])
       MSE <- MSE_data$MSE_data
       MSE_method <- MSE_data$MSE_method
     } else {
@@ -585,21 +599,31 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
       MSE_method <- "no mse estimated"
     }
     
+    if (correlation == "spatial"){
+    sigmau2 <- data.frame(correlation = unname(eblup$variance[1]), 
+                          variance = unname(eblup$variance[2]))
+    row.names(sigmau2) <- ""
+    } else if (correlation == "no"){
+      sigmau2 <- unname(eblup$variance[1])
+    }
     
     out <- list(ind = eblup$EBLUP_data,
                 MSE = MSE,
                 transform_param = NULL,
                 model = list(coefficients = eblup$coefficients,
-                             variance = eblup$variance,
+                             variance = sigmau2,
                              random_effects = as.matrix(eblup$random_effects),
+                             fitted = eblup$fitted,
                              real_residuals = as.matrix(eblup$real_res),
                              std_real_residuals = as.matrix(eblup$std_real_res),
                              correlation = correlation,
                              k = k,
-                             c = c,
-                             seed = seed),
+                             mult_constant = mult_constant,
+                             seed = seed,
+                             beta_vcov = eblup$beta_vcov),
                 framework = framework[c("direct", "vardir", "N_dom_smp",
-                                        "N_dom_unobs")],
+                                        "N_dom_unobs", "combined_data", 
+                                        "domains", "W")],
                 transformation = list(transformation = transformation,
                                       backtransformation = backtransformation),
                 method = list(method = method,
@@ -612,7 +636,7 @@ fh <- function(fixed, vardir, combined_data, domains = NULL, method = "reml",
   }
   
 
-  class(out) <- c("emdi", "model", "fh")
+  class(out) <- c("fh", "emdi")
 
   return(out)
 
