@@ -19,11 +19,11 @@ combine_data <- function(pop_data, pop_domains, smp_data, smp_domains) {
   smp_domains_vec <- smp_data[, smp_domains]
   pop_domains_vec <- pop_data[, pop_domains]
   
-  if(all(smp_domains_vec %in% pop_domains_vec) == FALSE) {
+  if (all(smp_domains_vec %in% pop_domains_vec) == FALSE) {
     stop("All sample domains need to be available in population domains.")
   }
-  if(all(pop_domains_vec %in% smp_domains_vec) == FALSE) {
-    cat("Non-sampled domains exist.\n")
+  if (all(pop_domains_vec %in% smp_domains_vec) == FALSE) {
+    message("Non-sampled domains exist.\n")
   }
 
   data <- merge(smp_data, pop_data, by.x = smp_domains, by.y = pop_domains,
